@@ -68,7 +68,7 @@ peas_gtk_configurable_create_configure_widget (PeasGtkConfigurable *configurable
 {
   PeasGtkConfigurableInterface *iface;
 
-  g_return_val_if_fail (PEAS_GTK_IS_CONFIGURABLE (configurable), FALSE);
+  g_return_val_if_fail (PEAS_GTK_IS_CONFIGURABLE (configurable), NULL);
 
   iface = PEAS_GTK_CONFIGURABLE_GET_IFACE (configurable);
 
